from fastapi import FastAPI, Path
from utils import create_connection, sql_to_df
import pandas as pd

app = FastAPI()

@app.get("/query/{query_name}/{json_format}")
async def root(
    query_name: str,
    json_format: str
):
    analysis_conn = create_connection("core.db")
    queries_conn = create_connection("queries.db")
    selected_query = list(queries_conn.execute(f"""
        select query_contents from queries where query_name = '{query_name}'
    """).fetchall())[0] 
    selected_query = selected_query[0]
    results_df = sql_to_df(analysis_conn, selected_query)
    return results_df.to_json(orient=json_format)




import streamlit as st
from utils import sql_to_df, create_connection
import requests


queries_conn = create_connection('queries.db')
queries_df = sql_to_df(queries_conn, 'select * from queries')
selected_query = st.selectbox('Query to Execute', list(queries_df['query_name']))

json_formats = ['split', 'records', 'index', 'columns', 'values', 'table']
selected_json_format = st.selectbox('Json Format', json_formats)

url = f'http://127.0.0.1:8002/query/{selected_query}/{selected_json_format}'

code = f"""
url = '{url}'
response = requests.get(url).json()
"""
st.code(code, language="python")

if st.button('Hit API'):
    response = requests.get(url).json()
    st.json(response)


import streamlit as st
import plotly.express as px
from utils import create_connection, sql_to_df, instantiate_queries_table
import os
import pandas as pd

st.write('# Delete Table')
analysis_conn = create_connection('core.db')

query = "SELECT name FROM sqlite_master WHERE type='table';"
df = sql_to_df(analysis_conn, query)
st.dataframe(df)
table_to_delete = st.selectbox('Table to Delete', list(df['name']))

if st.button('Delete'):
    statement = f"drop table '{table_to_delete}'"
    st.write(statement)
    analysis_conn.execute(statement)
    analysis_conn.commit()
    # results after
    analysis_df = sql_to_df(analysis_conn, query)
    st.dataframe(analysis_df)



import streamlit as st 
from utils import create_connection, instantiate_queries_table
import pandas as pd
import os


st.markdown("# Run Query")

query_name = st.text_input('Query Name')
st.write('When plotted the 1st column will be the x axis, 2nd will be the y axis')
query_contents = st.text_area("SQL Query", height=100)

analysis_conn = create_connection('core.db')
query_db_conn = create_connection('queries.db')

save_query = st.checkbox('Save Query')
run_query = st.button('Run Query')

if run_query:

    try:
        query = analysis_conn.execute(query_contents)

        cols = [column[0] for column in query.description]
        results_df= pd.DataFrame.from_records(
            data = query.fetchall(), 
            columns = cols
        )
        st.dataframe(results_df)
    except Exception as e:
        st.write(e)

    if save_query:

        instantiate_queries_table()
        
        # the streamlit input box will add a bunch of backslash Ns 
        query_contents = query_contents.replace('\n',' ')
        insert_statement = f"""
            insert into queries 
            (query_name, query_contents) 
            values 
            {query_name, query_contents};
        """

        # don't know where the extra brackets come from
        st.write(insert_statement) 
        insert_response = query_db_conn.execute(insert_statement)
        
        # I always forget to commit
        query_db_conn.commit()
        st.write(insert_response)

        url = f"localhost:8000/query/{query_name}"
        st.write(f'See API output at {url}')



import streamlit as st
import sqlite3
from pandas.core.frame import DataFrame
import pandas as pd

def create_connection(db_file):
    """ create a database connection to the SQLite database
        specified by the db_file
    :param db_file: database file
    :return: Connection object or None
    """
    conn = None
    try:
        conn = sqlite3.connect(db_file)
    except Exception as e:
        st.write(e)

    return conn


def instantiate_queries_table():
    try: 
        conn = create_connection('queries.db')
        conn.execute("""
            create table queries (query_name varchar, query_contents varchar);
        """
        )
        conn.commit()
        # always go for default index names when possible
        conn.execute("""
            CREATE UNIQUE INDEX IF NOT EXISTS
            ON queries(query_name);
        """
        )
        conn.commit()

    except:
        pass 


def sql_to_df(conn, query): 
    """
    Pandas does this well, maybe just copy there's
    """
    results = conn.execute(query)

    cols = [column[0] for column in results.description]
    results_df= pd.DataFrame.from_records(
        data = results.fetchall(), 
        columns = cols
    )
    return results_df


def delete_component(conn, query: str, column_name: str, delete_statement: str): 
    """
    Pandas does this well, maybe just copy there's
    """

    instantiate_queries_table()
    queries_df = sql_to_df(conn, query)
    st.dataframe(queries_df)
    query_to_delete = st.selectbox('Query to Delete', list(queries_df[column_name]))

    if st.button('Delete'):
        st.write(delete_statement)
        conn.execute(delete_statement)
        conn.commit()
        queries_df = sql_to_df(conn, query)
        st.dataframe(queries_df)



import streamlit as st
import plotly.express as px
from utils import create_connection, sql_to_df, instantiate_queries_table
import os
import pandas as pd

# Combine this component with delete table!

st.write('#Delete Query')
analysis_conn = create_connection('core.db')
queries_conn = create_connection("queries.db")

instantiate_queries_table()
queries_df = sql_to_df(queries_conn, 'select * from queries')
st.dataframe(queries_df)
query_to_delete = st.selectbox('Query to Delete', list(queries_df['query_name']))

if st.button('Delete'):
    statement = f"delete from queries where query_name = '{query_to_delete}'"
    st.write(statement)
    queries_conn.execute(statement)
    queries_conn.commit()
    queries_df = sql_to_df(queries_conn, 'select * from queries')
    st.dataframe(queries_df)



import subprocess


def main():
    """
    Almost definitely not required, just don't have a thorough knowledge of 
    creating command line tools
    """
    subprocess.run(["streamlit", "run", "app.py"])  



import streamlit as st
from utils import create_connection
import pandas as pd
import os

st.markdown("# Upload Data")
# https://discuss.streamlit.io/t/uploading-csv-and-excel-files/10866/2
table_name = st.text_input('Table Name to Insert')
conn = create_connection('core.db')
uploaded_file = st.file_uploader('Choose a file')
if uploaded_file is not None:
    #read csv
    try:
        df = pd.read_csv(uploaded_file)
        df.to_sql(name=table_name, con=conn)
        st.write('Data uploaded successfully. These are the first 5 rows.')
        st.dataframe(df.head(5))

    except Exception as e:
        st.write(e)


import streamlit as st
import plotly.express as px
from utils import create_connection, sql_to_df, instantiate_queries_table
import os
import pandas as pd

analysis_conn = create_connection('core.db')
queries_conn = create_connection("queries.db")

# in case it doesn't already exist
instantiate_queries_table()
queries_df = sql_to_df(queries_conn, 'select * from queries')
selected_query = st.selectbox('Query to Execute', list(queries_df['query_name']))

selected_mask = (queries_df['query_name'] == selected_query)
selected_query = queries_df[selected_mask]['query_contents'].iloc[0]

plot_options = [
    'bar',
    'line',
    'scatter',
]
plot_type = st.selectbox(
    'Plot Type', 
    plot_options
)

submitted = st.button('Run Analysis')


if submitted:
    try:
        results_df = sql_to_df(analysis_conn, selected_query)
        st.dataframe(results_df)

        x_axis = list(results_df.columns)[0]
        y_axis = list(results_df.columns)[1]

        # TODO: will replace with a case statement soon
        if plot_type == 'bar':
            fig = px.bar(
                results_df, 
                x=x_axis,
                y=y_axis, 
            )
        if plot_type == 'line':
            fig = px.line(
                results_df, 
                x=x_axis,
                y=y_axis, 
            )
        if plot_type == 'scatter':
            fig = px.scatter(
                results_df, 
                x=x_axis,
                y=y_axis, 
            )

        st.plotly_chart(fig, use_container_width=True)
    except Exception as e:
        st.write(e)


#!/usr/bin/env python

import os
from setuptools import setup

with open("./README.md", "r") as fh:
    long_description = fh.read()

with open('./requirements.txt') as f:
    requirements = f.readlines()

# https://www.geeksforgeeks.org/command-line-scripts-python-packaging/
setup(
    name='streamlit-business-intelligence',
    version='0.0.3',
    description='Python library for SQL Data Analysis',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/GeorgePearse/streamlit-projects/tree/master/streamlit-bi',
    author='George Pearse',
    author_email='georgehwp26@gmail.com',
    license='MIT',
    install_requires=requirements,
    entry_points ={
        'console_scripts': [
            'streamlit-business-intelligence = src.streamlit_business_intelligence:main'
        ]
    },
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.6',
    ]
)


import streamlit as st
from utils import create_connection

# make sure the db exists irrespective of where user comes from
create_connection('core.db')

with open("../README.md", "r") as fh:
    long_description = fh.read()

# just paste most of your medium arcticle here 
st.markdown(long_description)